<!doctype html>
<html>
  <head>
    <title>{{ pagetitle }}</title>
    <link rel="stylesheet" href="{{ static_url('pinnwand.css') }}" type="text/css">
    <link rel="shortcut icon" href="/static/favicon.png">
    <script type="text/javascript" src="{{ static_url('pinnwand.js') }}"></script>
  </head>
  <body>
    <header>
      <nav>
        <ul>
          <li>
            <a href="/"><img class="logo" src="/static/logo.png"></a>
          </li>
        </ul>
      </nav>
    </header>
    {% block body %}{% end %}
    <footer>
      {% raw handler.application.configuration.footer %}
      <button class="btn-link" id="toggle-color-scheme">Toggle color scheme</button>.
    </footer>
  </body>
</html>
